==> haskell-control-monad-free-0.6.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-control-monad-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: control-monad-free
version: 0.6.1
id: control-monad-free-0.6.1-64fD2vBsrr9nRjiHlGguM
key: control-monad-free-0.6.1-64fD2vBsrr9nRjiHlGguM
license: LicenseRef-PublicDomain
maintainer: pepeiborra@gmail.com
author: Luke Palmer, Pepe Iborra
stability: experimental
homepage: http://github.com/pepeiborra/control-monad-free
synopsis: Free monads and monad transformers
description:
    This package provides datatypes to construct Free monads,
    Free monad transformers, and useful instances. In addition it
    provides the constructs to avoid quadratic complexity of left
    associative bind, as explained in:
    .
    * Janis Voigtlander, /Asymptotic Improvement of Computations over Free Monads, MPC'\''08/
category: Control, Monads
abi: ee8e4fa38707f05341c24ca2d860f717
exposed: True
exposed-modules:
    Control.Monad.Free Control.Monad.Free.Improve
    Control.Monad.Free.Zip
import-dirs: /usr/lib/ghc-8.4.3/site-local/control-monad-free-0.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/control-monad-free-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/control-monad-free-0.6.1
hs-libraries: HScontrol-monad-free-0.6.1-64fD2vBsrr9nRjiHlGguM
depends:
    base-4.11.1.0 prelude-extras-0.4.0.3-CB1Z7OqksdX7iImPzZk6eV
    transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             prelude-extras-0.4.0.3-CB1Z7OqksdX7iImPzZk6eV=8a9a6e0e6ac835d824e945281598848a
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-control-monad-free/html/control-monad-free.haddock
haddock-html: /usr/share/doc/haskell-control-monad-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-control-monad-free-0.6.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-control-monad-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: control-monad-free
version: 0.6.2
id: control-monad-free-0.6.2-K5OsWkYY4J3IMyPprITsgT
key: control-monad-free-0.6.2-K5OsWkYY4J3IMyPprITsgT
license: LicenseRef-PublicDomain
maintainer: pepeiborra@gmail.com
author: Luke Palmer, Pepe Iborra
stability: stable
homepage: http://github.com/pepeiborra/control-monad-free
synopsis: Free monads and monad transformers
description:
    This package provides datatypes to construct Free monads,
    Free monad transformers, and useful instances. In addition it
    provides the constructs to avoid quadratic complexity of left
    associative bind, as explained in:
    .
    * Janis Voigtlander, /Asymptotic Improvement of Computations over Free Monads, MPC'\''08/
category: Control, Monads
abi: c6fcfe21f3a4cf57d8a795dae0dccc5d
exposed: True
exposed-modules:
    Control.Monad.Free Control.Monad.Free.Improve
    Control.Monad.Free.Zip
import-dirs: /usr/lib/ghc-8.6.1/site-local/control-monad-free-0.6.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/control-monad-free-0.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/control-monad-free-0.6.2
hs-libraries: HScontrol-monad-free-0.6.2-K5OsWkYY4J3IMyPprITsgT
depends:
    base-4.12.0.0 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-control-monad-free/html/control-monad-free.haddock
haddock-html: /usr/share/doc/haskell-control-monad-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
